@@ -1,3 +1,7 @@
+# -*- coding: utf-8 -*-
+# This file is part of Quark-Engine - https://github.com/quark-engine/quark-engine
+# See the file 'LICENSE' for copying permission.
+
 import json
 import os
 
@@ -10,6 +14,7 @@ from quark.freshquark import check_update
 from quark.logo import logo
 from quark.utils.out import print_success, print_info, print_warning
 from quark.utils.weight import Weight
+from quark import config
 
 logo()
 check_update()
@@ -35,9 +40,11 @@ check_update()
 @click.option(
     "-r",
     "--rule",
-    help="Rules folder need to be checked",
-    type=click.Path(exists=True, file_okay=False, dir_okay=True),
-    required=True,
+    help="Rules directory",
+    type=click.Path(exists=True, file_okay=True, dir_okay=True),
+    default=f"{config.HOME_DIR}quark-rules",
+    required=False,
+    show_default=True
 )
 @click.option(
     "-g",
@@ -64,7 +71,8 @@ def entry_point(summary, detail, apk, rule, output, graph, classification, thres
     """Quark is an Obfuscation-Neglect Android Malware Scoring System"""
 
     if summary:
-        # show summary report
+        # Show summary report
+
         # Load APK
         data = Quark(apk)
 
@@ -92,7 +100,7 @@ def entry_point(summary, detail, apk, rule, output, graph, classification, thres
             data.show_call_graph()
 
     if detail:
-        # show summary report
+        # Show detail report
 
         # Load APK
         data = Quark(apk)
@@ -138,9 +146,9 @@ def entry_point(summary, detail, apk, rule, output, graph, classification, thres
 
         json_report = data.get_json_report()
 
-        with open(output, "w") as f:
-            json.dump(json_report, f, indent=4)
-            f.close()
+        with open(output, "w") as file:
+            json.dump(json_report, file, indent=4)
+            file.close()
 
 
 if __name__ == "__main__":
