@@ -22,14 +22,17 @@ class Forensic:
     def get_all_strings(self):
         """
         Return all the strings inside the APK with a set.
+        :return: a set of strings containing all strings
         """
+
         return self.all_strings
 
     def get_url(self):
         """
         Return all the url strings inside the APK with a set.
+        :return: a set of strings containing the url
         """
-
+        
         url = set()
 
         for string in self.all_strings:
@@ -43,6 +46,7 @@ class Forensic:
     def get_ip(self):
         """
         Return all the ip address strings inside the APK with a set.
+        :return: a set of strings containing the ip address
         """
 
         ip = set()
@@ -59,7 +63,9 @@ class Forensic:
     def get_content(self):
         """
         Return all the content strings inside the APK with a set.
+        :return: a set of strings containing "content://"
         """
+
         content = set()
 
         for string in self.all_strings:
@@ -71,8 +77,10 @@ class Forensic:
 
     def get_file(self):
         """
-        Return all the content strings inside the APK with a set.
+        Return all the file strings inside the APK with a set.
+        :return: a set of strings containing "file://"
         """
+
         file = set()
 
         for string in self.all_strings:
@@ -83,6 +91,10 @@ class Forensic:
         return file
 
     def get_base64(self):
+        """
+        Return all possible Base64-encoded strings in the APK.
+        :return: a set of strings containing possible Base64-encoded string
+        """
 
         base64 = set()
 
@@ -95,29 +107,4 @@ class Forensic:
 
 
 if __name__ == "__main__":
-    # Usage
-
-    # fc = Forensic("../sample/13667fe3b0ad496a0cd157f34b7e0c991d72a4db.apk")
-    # fc = Forensic("../sample/14d9f1a92dd984d6040cc41ed06e273e.apk")
-    # fc = Forensic("../sample/HippoSMS.apk")
-    fc = Forensic("../sample/obfuscation/com.cdim.driver.core.apk")
-
-    print("URL Found")
-    for i in fc.get_url():
-        print(i)
-
-    print("IP Found")
-    for i in fc.get_ip():
-        print(i)
-
-    print("Content Found")
-    for i in fc.get_content():
-        print(i)
-
-    print("FILE Found")
-    for i in fc.get_file():
-        print(i)
-
-    print("Base64 Found")
-    for i in fc.get_base64():
-        print(i)
+    pass
